@@ -39,9 +39,9 @@ Holds the last error.
 
 =cut
 
-has ioloop => sub { Mojo::IOLoop->singleton };
+has ioloop             => sub { Mojo::IOLoop->singleton };
 has message_processing => sub { Net::SNMP::MessageProcessing->instance };
-has debug => 0; # Use MOJO_SNMP_DEBUG=1 instead
+has debug => 0;    # Use MOJO_SNMP_DEBUG=1 instead
 
 =head2 connections
 
@@ -49,10 +49,10 @@ Holds the number of active sockets.
 
 =cut
 
-sub connections { int values %{ $_[0]->{descriptors} } }
+sub connections { int values %{$_[0]->{descriptors}} }
 
 sub error {
-  my($self, $format, @args) = @_;
+  my ($self, $format, @args) = @_;
 
   return $self->{error} if @_ == 1;
   $self->{error} = defined $format ? sprintf $format, @args : undef;
@@ -69,9 +69,9 @@ This method will send a PDU to the SNMP server.
 =cut
 
 sub send_pdu {
-  my($self, $pdu, $delay) = @_;
+  my ($self, $pdu, $delay) = @_;
 
-  unless(ref $pdu) {
+  unless (ref $pdu) {
     $self->error('The required PDU object is missing or invalid');
     return FALSE;
   }
@@ -110,12 +110,12 @@ do the heavy lifting.
 =cut
 
 sub schedule {
-  my($self, $time, $callback) = @_;
+  my ($self, $time, $callback) = @_;
   my $code = shift @$callback;
 
   warn "[DISPATCHER] Schedule $time $code(@$callback)\n" if DEBUG;
 
-  if($time) {
+  if ($time) {
     Scalar::Util::weaken($self);
     $self->ioloop->timer($time => sub { $self->$code(@$callback) });
   }
@@ -131,23 +131,26 @@ Register a new transport object with L<Mojo::IOLoop::Reactor>.
 =cut
 
 sub register {
-  my($self, $transport) = @_;
+  my ($self, $transport) = @_;
   my $reactor = $self->ioloop->reactor;
   my $fileno;
 
-  unless(defined $transport and defined($fileno = $transport->fileno)) {
+  unless (defined $transport and defined($fileno = $transport->fileno)) {
     $self->error('The Transport Domain object is invalid');
     return FALSE;
   }
 
-  if($self->{descriptors}{$fileno}++) {
+  if ($self->{descriptors}{$fileno}++) {
     return $transport;
   }
 
   Scalar::Util::weaken($self);
-  $reactor->io($transport->socket, sub {
-    $self->_transport_response_received($transport);
-  });
+  $reactor->io(
+    $transport->socket,
+    sub {
+      $self->_transport_response_received($transport);
+    }
+  );
 
   $reactor->watch($transport->socket, 1, 0);
   warn "[DISPATCHER] Add handler for descriptor $fileno\n" if DEBUG;
@@ -161,7 +164,7 @@ The opposite of L</register>.
 =cut
 
 sub deregister {
-  my($self, $transport) = @_;
+  my ($self, $transport) = @_;
   my $fileno = $transport->fileno;
   return if --$self->{descriptors}{$fileno} > 0;
   delete $self->{descriptors}{$fileno};
@@ -170,20 +173,20 @@ sub deregister {
 }
 
 sub _send_pdu {
-  my($self, $pdu, $retries) = @_;
-  my $mp = $self->message_processing;
+  my ($self, $pdu, $retries) = @_;
+  my $mp  = $self->message_processing;
   my $msg = $mp->prepare_outgoing_msg($pdu);
 
-  unless(defined $msg) {
+  unless (defined $msg) {
     warn "[DISPATCHER] prepare_outgoing_msg: @{[$mp->error]}\n" if DEBUG;
     $pdu->status_information($mp->error);
     return;
   }
-  unless(defined $msg->send) {
-    if($pdu->expect_response) {
-      $mp->msg_handle_delete($msg->msg_id)
+  unless (defined $msg->send) {
+    if ($pdu->expect_response) {
+      $mp->msg_handle_delete($msg->msg_id);
     }
-    if($retries-- > 0 and $!{EAGAIN} or $!{EWOULDBLOCK}) {
+    if ($retries-- > 0 and $!{EAGAIN} or $!{EWOULDBLOCK}) {
       warn "[DISPATCHER] Attempt to recover from temporary failure: $!\n" if DEBUG;
       $self->schedule($pdu->timeout, [_send_pdu => $pdu, $retries]);
       return FALSE;
@@ -193,28 +196,21 @@ sub _send_pdu {
     return;
   }
 
-  if($pdu->expect_response) {
+  if ($pdu->expect_response) {
     $self->register($msg->transport);
-    $msg->timeout_id(
-      $self->schedule($pdu->timeout, [
-        '_transport_timeout',
-        $pdu,
-        $retries,
-        $msg->msg_id,
-      ])
-    );
+    $msg->timeout_id($self->schedule($pdu->timeout, ['_transport_timeout', $pdu, $retries, $msg->msg_id,]));
   }
 
   return TRUE;
 }
 
 sub _transport_timeout {
-  my($self, $pdu, $retries, $handle) = @_;
+  my ($self, $pdu, $retries, $handle) = @_;
 
   $self->deregister($pdu->transport);
   $self->message_processing->msg_handle_delete($handle);
 
-  if($retries-- > 0) {
+  if ($retries-- > 0) {
     warn "[DISPATCHER] Retries left: $retries\n" if DEBUG;
     return $self->_send_pdu($pdu, $retries);
   }
@@ -226,29 +222,29 @@ sub _transport_timeout {
 }
 
 sub _transport_response_received {
-  my($self, $transport) = @_;
+  my ($self, $transport) = @_;
   my $mp = $self->message_processing;
-  my($msg, $error) = Net::SNMP::Message->new(-transport => $transport);
+  my ($msg, $error) = Net::SNMP::Message->new(-transport => $transport);
 
   $self->error(undef);
 
-  if(not defined $msg) {
+  if (not defined $msg) {
     die sprintf 'Failed to create Message object: %s', $error;
   }
-  if(not defined $msg->recv) {
+  if (not defined $msg->recv) {
     $self->error($msg->error);
     $self->deregister($transport) unless $transport->connectionless;
     return;
   }
-  if(not $msg->length) {
+  if (not $msg->length) {
     warn "[DISPATCHER] Ignoring zero length message\n" if DEBUG;
     return;
   }
-  if(not $mp->prepare_data_elements($msg)) {
+  if (not $mp->prepare_data_elements($msg)) {
     $self->error($mp->error);
     return;
   }
-  if($mp->error) {
+  if ($mp->error) {
     $msg->error($mp->error);
   }
 
